@@ -61,8 +61,8 @@ namespace { // anonymous namespace
 struct OutputOptions {
     bool quiet = false;
     bool PROJ5 = false;
-    bool WKT2_2018 = false;
-    bool WKT2_2018_SIMPLIFIED = false;
+    bool WKT2_2019 = false;
+    bool WKT2_2019_SIMPLIFIED = false;
     bool WKT2_2015 = false;
     bool WKT2_2015_SIMPLIFIED = false;
     bool WKT1_GDAL = false;
@@ -95,14 +95,14 @@ static void usage() {
         << "                [--boundcrs-to-wgs84]" << std::endl
         << "                [--main-db-path path] [--aux-db-path path]*"
         << std::endl
-        << "                [--identify]" << std::endl
+        << "                [--identify] [--3d]" << std::endl
         << "                [--c-ify] [--single-line]" << std::endl
         << "                {object_definition} | (-s {srs_def} -t {srs_def})"
         << std::endl;
     std::cerr << std::endl;
     std::cerr << "-o: formats is a comma separated combination of: "
-                 "all,default,PROJ,WKT_ALL,WKT2_2015,WKT2_2018,WKT1_GDAL,"
-                 "WKT1_ESRI,PROJJSON"
+                 "all,default,PROJ,WKT_ALL,WKT2:2015,WKT2:2019,WKT1:GDAL,"
+                 "WKT1:ESRI,PROJJSON"
               << std::endl;
     std::cerr << "    Except 'all' and 'default', other format can be preceded "
                  "by '-' to disable them"
@@ -143,7 +143,7 @@ static BaseObjectNNPtr buildObject(
     const std::string &kind, const std::string &context,
     bool buildBoundCRSToWGS84,
     CoordinateOperationContext::IntermediateCRSUse allowUseIntermediateCRS,
-    bool quiet) {
+    bool promoteTo3D, bool quiet) {
     BaseObjectPtr obj;
 
     std::string l_user_string(user_string);
@@ -225,6 +225,13 @@ static BaseObjectNNPtr buildObject(
         }
     }
 
+    if (promoteTo3D) {
+        auto crs = std::dynamic_pointer_cast<CRS>(obj);
+        if (crs) {
+            obj = crs->promoteTo3D(std::string(), dbContext).as_nullable();
+        }
+    }
+
     return NN_NO_CHECK(obj);
 }
 
@@ -309,7 +316,7 @@ static void outputObject(
                     std::cout << std::endl;
                 }
                 if (!outputOpt.quiet) {
-                    std::cout << "WKT2_2015 string:" << std::endl;
+                    std::cout << "WKT2:2015 string:" << std::endl;
                 }
                 auto formatter =
                     WKTFormatter::create(WKTFormatter::Convention::WKT2_2015);
@@ -323,7 +330,7 @@ static void outputObject(
                 }
                 std::cout << wkt << std::endl;
             } catch (const std::exception &e) {
-                std::cerr << "Error when exporting to WKT2_2015: " << e.what()
+                std::cerr << "Error when exporting to WKT2:2015: " << e.what()
                           << std::endl;
             }
             alreadyOutputed = true;
@@ -335,7 +342,7 @@ static void outputObject(
                     std::cout << std::endl;
                 }
                 if (!outputOpt.quiet) {
-                    std::cout << "WKT2_2015_SIMPLIFIED string:" << std::endl;
+                    std::cout << "WKT2:2015_SIMPLIFIED string:" << std::endl;
                 }
                 auto formatter = WKTFormatter::create(
                     WKTFormatter::Convention::WKT2_2015_SIMPLIFIED);
@@ -349,22 +356,22 @@ static void outputObject(
                 }
                 std::cout << wkt << std::endl;
             } catch (const std::exception &e) {
-                std::cerr << "Error when exporting to WKT2_2015_SIMPLIFIED: "
+                std::cerr << "Error when exporting to WKT2:2015_SIMPLIFIED: "
                           << e.what() << std::endl;
             }
             alreadyOutputed = true;
         }
 
-        if (outputOpt.WKT2_2018) {
+        if (outputOpt.WKT2_2019) {
             try {
                 if (alreadyOutputed) {
                     std::cout << std::endl;
                 }
                 if (!outputOpt.quiet) {
-                    std::cout << "WKT2_2018 string:" << std::endl;
+                    std::cout << "WKT2:2019 string:" << std::endl;
                 }
                 auto formatter =
-                    WKTFormatter::create(WKTFormatter::Convention::WKT2_2018);
+                    WKTFormatter::create(WKTFormatter::Convention::WKT2_2019);
                 if (outputOpt.singleLine) {
                     formatter->setMultiLine(false);
                 }
@@ -375,22 +382,22 @@ static void outputObject(
                 }
                 std::cout << wkt << std::endl;
             } catch (const std::exception &e) {
-                std::cerr << "Error when exporting to WKT2_2018: " << e.what()
+                std::cerr << "Error when exporting to WKT2:2019: " << e.what()
                           << std::endl;
             }
             alreadyOutputed = true;
         }
 
-        if (outputOpt.WKT2_2018_SIMPLIFIED) {
+        if (outputOpt.WKT2_2019_SIMPLIFIED) {
             try {
                 if (alreadyOutputed) {
                     std::cout << std::endl;
                 }
                 if (!outputOpt.quiet) {
-                    std::cout << "WKT2_2018_SIMPLIFIED string:" << std::endl;
+                    std::cout << "WKT2:2019_SIMPLIFIED string:" << std::endl;
                 }
                 auto formatter = WKTFormatter::create(
-                    WKTFormatter::Convention::WKT2_2018_SIMPLIFIED);
+                    WKTFormatter::Convention::WKT2_2019_SIMPLIFIED);
                 if (outputOpt.singleLine) {
                     formatter->setMultiLine(false);
                 }
@@ -401,7 +408,7 @@ static void outputObject(
                 }
                 std::cout << wkt << std::endl;
             } catch (const std::exception &e) {
-                std::cerr << "Error when exporting to WKT2_2018_SIMPLIFIED: "
+                std::cerr << "Error when exporting to WKT2:2019_SIMPLIFIED: "
                           << e.what() << std::endl;
             }
             alreadyOutputed = true;
@@ -413,18 +420,7 @@ static void outputObject(
                     std::cout << std::endl;
                 }
                 if (!outputOpt.quiet) {
-                    std::cout << "WKT1_GDAL:" << std::endl;
-                }
-
-                auto crs = nn_dynamic_pointer_cast<CRS>(obj);
-                std::shared_ptr<IWKTExportable> objToExport;
-                if (crs) {
-                    objToExport = nn_dynamic_pointer_cast<IWKTExportable>(
-                        crs->createBoundCRSToWGS84IfPossible(
-                            dbContext, allowUseIntermediateCRS));
-                }
-                if (!objToExport) {
-                    objToExport = wktExportable;
+                    std::cout << "WKT1:GDAL string:" << std::endl;
                 }
 
                 auto formatter =
@@ -433,14 +429,14 @@ static void outputObject(
                     formatter->setMultiLine(false);
                 }
                 formatter->setStrict(outputOpt.strict);
-                auto wkt = objToExport->exportToWKT(formatter.get());
+                auto wkt = wktExportable->exportToWKT(formatter.get());
                 if (outputOpt.c_ify) {
                     wkt = c_ify_string(wkt);
                 }
                 std::cout << wkt << std::endl;
                 std::cout << std::endl;
             } catch (const std::exception &e) {
-                std::cerr << "Error when exporting to WKT1_GDAL: " << e.what()
+                std::cerr << "Error when exporting to WKT1:GDAL: " << e.what()
                           << std::endl;
             }
             alreadyOutputed = true;
@@ -452,7 +448,7 @@ static void outputObject(
                     std::cout << std::endl;
                 }
                 if (!outputOpt.quiet) {
-                    std::cout << "WKT1_ESRI:" << std::endl;
+                    std::cout << "WKT1:ESRI string:" << std::endl;
                 }
 
                 auto formatter = WKTFormatter::create(
@@ -465,7 +461,7 @@ static void outputObject(
                 std::cout << wkt << std::endl;
                 std::cout << std::endl;
             } catch (const std::exception &e) {
-                std::cerr << "Error when exporting to WKT1_ESRI: " << e.what()
+                std::cerr << "Error when exporting to WKT1:ESRI: " << e.what()
                           << std::endl;
             }
             alreadyOutputed = true;
@@ -604,24 +600,29 @@ static void outputOperations(
     CoordinateOperationContext::IntermediateCRSUse allowUseIntermediateCRS,
     const std::vector<std::pair<std::string, std::string>> &pivots,
     const std::string &authority, bool usePROJGridAlternatives,
-    bool showSuperseded, const OutputOptions &outputOpt, bool summary) {
-    auto sourceObj = buildObject(
-        dbContext, sourceCRSStr, "crs", "source CRS", false,
-        CoordinateOperationContext::IntermediateCRSUse::NEVER, outputOpt.quiet);
+    bool showSuperseded, bool promoteTo3D, const OutputOptions &outputOpt,
+    bool summary) {
+    auto sourceObj =
+        buildObject(dbContext, sourceCRSStr, "crs", "source CRS", false,
+                    CoordinateOperationContext::IntermediateCRSUse::NEVER,
+                    promoteTo3D, outputOpt.quiet);
     auto sourceCRS = nn_dynamic_pointer_cast<CRS>(sourceObj);
     if (!sourceCRS) {
         std::cerr << "source CRS string is not a CRS" << std::endl;
         std::exit(1);
     }
+    auto nnSourceCRS = NN_NO_CHECK(sourceCRS);
 
-    auto targetObj = buildObject(
-        dbContext, targetCRSStr, "crs", "target CRS", false,
-        CoordinateOperationContext::IntermediateCRSUse::NEVER, outputOpt.quiet);
+    auto targetObj =
+        buildObject(dbContext, targetCRSStr, "crs", "target CRS", false,
+                    CoordinateOperationContext::IntermediateCRSUse::NEVER,
+                    promoteTo3D, outputOpt.quiet);
     auto targetCRS = nn_dynamic_pointer_cast<CRS>(targetObj);
     if (!targetCRS) {
         std::cerr << "target CRS string is not a CRS" << std::endl;
         std::exit(1);
     }
+    auto nnTargetCRS = NN_NO_CHECK(targetCRS);
 
     std::vector<CoordinateOperationNNPtr> list;
     size_t spatialCriterionPartialIntersectionResultCount = 0;
@@ -641,7 +642,7 @@ static void outputOperations(
         ctxt->setUsePROJAlternativeGridNames(usePROJGridAlternatives);
         ctxt->setDiscardSuperseded(!showSuperseded);
         list = CoordinateOperationFactory::create()->createOperations(
-            NN_NO_CHECK(sourceCRS), NN_NO_CHECK(targetCRS), ctxt);
+            nnSourceCRS, nnTargetCRS, ctxt);
         if (!spatialCriterionExplicitlySpecified &&
             spatialCriterion == CoordinateOperationContext::SpatialCriterion::
                                     STRICT_CONTAINMENT) {
@@ -651,8 +652,7 @@ static void outputOperations(
                         PARTIAL_INTERSECTION);
                 spatialCriterionPartialIntersectionResultCount =
                     CoordinateOperationFactory::create()
-                        ->createOperations(NN_NO_CHECK(sourceCRS),
-                                           NN_NO_CHECK(targetCRS), ctxt)
+                        ->createOperations(nnSourceCRS, nnTargetCRS, ctxt)
                         .size();
             } catch (const std::exception &) {
             }
@@ -735,6 +735,7 @@ int main(int argc, char **argv) {
     std::string authority;
     bool identify = false;
     bool showSuperseded = false;
+    bool promoteTo3D = false;
 
     for (int i = 1; i < argc; i++) {
         std::string arg(argv[i]);
@@ -745,14 +746,14 @@ int main(int argc, char **argv) {
             for (auto format : formats) {
                 if (ci_equal(format, "all")) {
                     outputOpt.PROJ5 = true;
-                    outputOpt.WKT2_2018 = true;
+                    outputOpt.WKT2_2019 = true;
                     outputOpt.WKT2_2015 = true;
                     outputOpt.WKT1_GDAL = true;
                     outputOpt.WKT1_ESRI = true;
                     outputOpt.PROJJSON = true;
                 } else if (ci_equal(format, "default")) {
                     outputOpt.PROJ5 = true;
-                    outputOpt.WKT2_2018 = true;
+                    outputOpt.WKT2_2019 = true;
                     outputOpt.WKT2_2015 = false;
                     outputOpt.WKT1_GDAL = false;
                 } else if (ci_equal(format, "PROJ")) {
@@ -761,26 +762,38 @@ int main(int argc, char **argv) {
                     outputOpt.PROJ5 = false;
                 } else if (ci_equal(format, "WKT_ALL") ||
                            ci_equal(format, "WKT-ALL")) {
-                    outputOpt.WKT2_2018 = true;
+                    outputOpt.WKT2_2019 = true;
                     outputOpt.WKT2_2015 = true;
                     outputOpt.WKT1_GDAL = true;
                 } else if (ci_equal(format, "-WKT_ALL") ||
                            ci_equal(format, "-WKT-ALL")) {
-                    outputOpt.WKT2_2018 = false;
+                    outputOpt.WKT2_2019 = false;
                     outputOpt.WKT2_2015 = false;
                     outputOpt.WKT1_GDAL = false;
-                } else if (ci_equal(format, "WKT2_2018") ||
+                } else if (ci_equal(format, "WKT2_2019") ||
+                           ci_equal(format, "WKT2-2019") ||
+                           ci_equal(format, "WKT2:2019") ||
+                           /* legacy: undocumented */
+                           ci_equal(format, "WKT2_2018") ||
                            ci_equal(format, "WKT2-2018") ||
                            ci_equal(format, "WKT2:2018")) {
-                    outputOpt.WKT2_2018 = true;
-                } else if (ci_equal(format, "WKT2_2018_SIMPLIFIED") ||
+                    outputOpt.WKT2_2019 = true;
+                } else if (ci_equal(format, "WKT2_2019_SIMPLIFIED") ||
+                           ci_equal(format, "WKT2-2019_SIMPLIFIED") ||
+                           ci_equal(format, "WKT2:2019_SIMPLIFIED") ||
+                           /* legacy: undocumented */
+                           ci_equal(format, "WKT2_2018_SIMPLIFIED") ||
                            ci_equal(format, "WKT2-2018_SIMPLIFIED") ||
                            ci_equal(format, "WKT2:2018_SIMPLIFIED")) {
-                    outputOpt.WKT2_2018_SIMPLIFIED = true;
-                } else if (ci_equal(format, "-WKT2_2018") ||
+                    outputOpt.WKT2_2019_SIMPLIFIED = true;
+                } else if (ci_equal(format, "-WKT2_2019") ||
+                           ci_equal(format, "-WKT2-2019") ||
+                           ci_equal(format, "-WKT2:2019") ||
+                           /* legacy: undocumented */
+                           ci_equal(format, "-WKT2_2018") ||
                            ci_equal(format, "-WKT2-2018") ||
                            ci_equal(format, "-WKT2:2018")) {
-                    outputOpt.WKT2_2018 = false;
+                    outputOpt.WKT2_2019 = false;
                 } else if (ci_equal(format, "WKT2_2015") ||
                            ci_equal(format, "WKT2-2015") ||
                            ci_equal(format, "WKT2:2015")) {
@@ -972,6 +985,8 @@ int main(int argc, char **argv) {
             showSuperseded = true;
         } else if (arg == "--lax") {
             outputOpt.strict = false;
+        } else if (ci_equal(arg, "--3d")) {
+            promoteTo3D = true;
         } else if (arg == "-?" || arg == "--help") {
             usage();
         } else if (arg[0] == '-') {
@@ -1027,11 +1042,11 @@ int main(int argc, char **argv) {
 
     if (!outputSwithSpecified) {
         outputOpt.PROJ5 = true;
-        outputOpt.WKT2_2018 = true;
+        outputOpt.WKT2_2019 = true;
     }
 
     if (outputOpt.quiet &&
-        (outputOpt.PROJ5 + outputOpt.WKT2_2018 + outputOpt.WKT2_2015 +
+        (outputOpt.PROJ5 + outputOpt.WKT2_2019 + outputOpt.WKT2_2015 +
          outputOpt.WKT1_GDAL + outputOpt.PROJJSON) != 1) {
         std::cerr << "-q can only be used with a single output format"
                   << std::endl;
@@ -1042,12 +1057,13 @@ int main(int argc, char **argv) {
         try {
             auto obj(buildObject(dbContext, user_string, objectKind,
                                  "input string", buildBoundCRSToWGS84,
-                                 allowUseIntermediateCRS, outputOpt.quiet));
+                                 allowUseIntermediateCRS, promoteTo3D,
+                                 outputOpt.quiet));
             if (guessDialect) {
                 auto dialect = WKTParser().guessDialect(user_string);
                 std::cout << "Guessed WKT dialect: ";
-                if (dialect == WKTParser::WKTGuessedDialect::WKT2_2018) {
-                    std::cout << "WKT2_2018";
+                if (dialect == WKTParser::WKTGuessedDialect::WKT2_2019) {
+                    std::cout << "WKT2_2019";
                 } else if (dialect == WKTParser::WKTGuessedDialect::WKT2_2015) {
                     std::cout << "WKT2_2015";
                 } else if (dialect == WKTParser::WKTGuessedDialect::WKT1_GDAL) {
@@ -1181,7 +1197,7 @@ int main(int argc, char **argv) {
                              spatialCriterionExplicitlySpecified, crsExtentUse,
                              gridAvailabilityUse, allowUseIntermediateCRS,
                              pivots, authority, usePROJGridAlternatives,
-                             showSuperseded, outputOpt, summary);
+                             showSuperseded, promoteTo3D, outputOpt, summary);
         } catch (const std::exception &e) {
             std::cerr << "outputOperations() failed with: " << e.what()
                       << std::endl;
