@@ -1,7 +1,7 @@
 /******************************************************************************
  *
  * Project:  PROJ
- * Purpose:  Test ISO19111:2018 implementation
+ * Purpose:  Test ISO19111:2019 implementation
  * Author:   Even Rouault <even dot rouault at spatialys dot com>
  *
  ******************************************************************************
@@ -44,7 +44,8 @@ namespace {
 struct UnrelatedObject : public IComparable {
     UnrelatedObject() = default;
 
-    bool _isEquivalentTo(const IComparable *, Criterion) const override {
+    bool _isEquivalentTo(const IComparable *, Criterion,
+                         const DatabaseContextPtr &) const override {
         assert(false);
         return false;
     }
@@ -273,7 +274,7 @@ TEST(datum, dynamic_geodetic_reference_frame) {
 
     EXPECT_EQ(drf->exportToWKT(WKTFormatter::create().get()), expected);
 
-    auto expected_wtk2_2018 =
+    auto expected_wtk2_2019 =
         "DYNAMIC[\n"
         "    FRAMEEPOCH[2018.5],\n"
         "    MODEL[\"My model\"]],\n"
@@ -284,8 +285,8 @@ TEST(datum, dynamic_geodetic_reference_frame) {
         "    ANCHOR[\"My anchor\"]]";
     EXPECT_EQ(
         drf->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
-        expected_wtk2_2018);
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
+        expected_wtk2_2019);
 }
 
 // ---------------------------------------------------------------------------
@@ -355,7 +356,7 @@ TEST(datum, temporal_datum_time_origin_non_ISO8601) {
 
 // ---------------------------------------------------------------------------
 
-TEST(datum, temporal_datum_WKT2_2018) {
+TEST(datum, temporal_datum_WKT2_2019) {
     auto datum = TemporalDatum::create(
         PropertyMap().set(IdentifiedObject::NAME_KEY, "Gregorian calendar"),
         DateTime::create("0000-01-01"),
@@ -367,7 +368,7 @@ TEST(datum, temporal_datum_WKT2_2018) {
 
     EXPECT_EQ(
         datum->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
         expected);
 }
 
@@ -385,15 +386,15 @@ TEST(datum, dynamic_vertical_reference_frame) {
 
     EXPECT_EQ(drf->exportToWKT(WKTFormatter::create().get()), expected);
 
-    auto expected_wtk2_2018 = "DYNAMIC[\n"
+    auto expected_wtk2_2019 = "DYNAMIC[\n"
                               "    FRAMEEPOCH[2018.5],\n"
                               "    MODEL[\"My model\"]],\n"
                               "VDATUM[\"test\",\n"
                               "    ANCHOR[\"My anchor\"]]";
     EXPECT_EQ(
         drf->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
-        expected_wtk2_2018);
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
+        expected_wtk2_2019);
 }
 
 // ---------------------------------------------------------------------------
@@ -412,7 +413,7 @@ TEST(datum, datum_ensemble) {
                  FormattingException);
     EXPECT_EQ(
         ensemble->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
         "ENSEMBLE[\"test\",\n"
         "    MEMBER[\"World Geodetic System 1984\",\n"
         "        ID[\"EPSG\",6326]],\n"
@@ -436,7 +437,7 @@ TEST(datum, datum_ensemble_vertical) {
         PositionalAccuracy::create("100"));
     EXPECT_EQ(
         ensemble->exportToWKT(
-            WKTFormatter::create(WKTFormatter::Convention::WKT2_2018).get()),
+            WKTFormatter::create(WKTFormatter::Convention::WKT2_2019).get()),
         "ENSEMBLE[\"unnamed\",\n"
         "    MEMBER[\"vdatum1\"],\n"
         "    MEMBER[\"vdatum2\"],\n"
